@@ -46,7 +46,7 @@ class K3SRepository(Repository):
     def create_namespace(self, cluster_name: Name, namespace_name: Name)->bool:
         raise NotImplementedError
 
-    def create_node(self, condition: Condition, node_user_setting: NodeUserSetting)->Optional[NodeInfo]:
+    def create_node(self, condition: Condition, node_user_setting: NodeUserSetting)->Optional[List[NodeInfo]]:
         raise NotImplementedError
 
     def create_resource_from_oss(self, cluster_name: Name, target_paths: List[Path])->bool:
