@@ -4,6 +4,10 @@ from ddd_objects.domain.exception import ParameterError, FormatError
 
 class Number(ExpiredValueObject):
     def __init__(self, value):
+        try:
+            value = float(value)
+        except:
+            raise FormatError(f'The given value ({value}) is not a Number')
         super().__init__(value, None)
 
 class Size(ExpiredValueObject):
