@@ -58,12 +58,12 @@ class K3SController:
         }
         data = json.dumps(data)
         response=requests.post(f'{self.url}/node', headers=self.header, data=data, timeout=timeout)
-        info = json.loads(response.text)
-        self._check_error(response.status_code, info)
-        if info is None:
+        infos = json.loads(response.text)
+        self._check_error(response.status_code, infos)
+        if infos is None:
             return None
         else:
-            return NodeInfoDO(**info)
+            return [NodeInfoDO(**info) for info in infos]
 
     @exception_class_dec(max_try=1)
     def delete_nodes(self, node_infos: List[Union[NodeInfoDO, NodeMetaDO]], timeout=60):
