@@ -2,111 +2,111 @@ from shutil import disk_usage
 from typing import List
 from ddd_objects.infrastructure.converter import Converter
 from ..domain.entity import (
-    PodContainer,
-    Deployment,
-    InstanceUserSetting,
-    SecretUserSetting,
-    Ingress,
-    InstanceInfo,
-    Condition,
     DNSRecord,
-    InstanceTypeUserSetting,
-    Pod,
-    ConfigMapUserSetting,
-    PodOSSOperationInfo,
-    Service,
-    InstanceTypeWithStatus,
-    ResourceOSSSetting,
-    Namespace,
-    CommandSetting,
+    NodeInfo,
     NodeUserSetting,
-    OSSOperationInfo,
-    Secret,
-    NodeMeta,
-    CommandResult,
+    Pod,
+    SecretUserSetting,
+    Namespace,
     ConfigMap,
-    NodeInfo
+    Secret,
+    OSSOperationInfo,
+    Deployment,
+    Condition,
+    PodContainer,
+    InstanceTypeWithStatus,
+    InstanceUserSetting,
+    ResourceOSSSetting,
+    InstanceInfo,
+    CommandResult,
+    ConfigMapUserSetting,
+    NodeMeta,
+    CommandSetting,
+    Service,
+    InstanceTypeUserSetting,
+    PodOSSOperationInfo,
+    Ingress
 )
 from ..domain.value_obj import (
-    KeyType,
-    NodeType,
-    Bool,
-    DNSLine,
-    Username,
-    Token,
-    RegionID,
-    Key,
-    InternetPayType,
-    Endpoint,
-    Time,
-    ZoneID,
-    InstanceTypeStatus,
-    Usage,
-    TimeInterval,
-    BandWidth,
     PayType,
-    Path,
     Value,
-    DateTime,
+    Number,
+    BandWidth,
+    DNSType,
+    GPUType,
+    NodeName,
+    Subdomain,
+    ZoneID,
+    Bool,
+    Time,
+    Path,
+    Port,
+    Version,
+    Password,
+    ServiceType,
+    DNSLine,
+    SecurityGroupID,
+    NodeType,
+    KeyType,
+    DomainName,
+    RegionID,
+    RecordID,
+    Price,
+    Token,
+    NodeLabel,
+    Output,
+    Command,
+    Size,
+    InstanceID,
+    Key,
+    Endpoint,
     Name,
+    InstanceName,
+    Type,
+    InstanceTypeStatus,
+    Hostname,
+    InternetPayType,
+    ImageID,
+    Usage,
+    NodeStatus,
     Info,
     Weight,
-    NodeStatus,
-    RecordID,
-    InstanceType,
-    NodeLabel,
-    Version,
-    NodeName,
-    InstanceName,
-    Size,
-    Data,
-    GPUType,
-    ServiceType,
-    Password,
-    IP,
-    ImageID,
-    Hostname,
-    SecurityGroupID,
-    DNSType,
-    Number,
-    Subdomain,
-    Command,
-    InstanceID,
-    Port,
-    DomainName,
-    Status,
-    PodStatus,
-    Output,
-    Type,
-    InstanceTypeStatusCategory,
     ID,
-    Price
+    PodStatus,
+    InstanceType,
+    DateTime,
+    TimeInterval,
+    InstanceTypeStatusCategory,
+    Data,
+    IP,
+    Username,
+    Status
 )
 from .do import (
-    DNSRecordDO,
-    NamespaceDO,
-    IngressDO,
-    NodeUserSettingDO,
-    CommandResultDO,
-    ConfigMapDO,
-    ConditionDO,
-    DeploymentDO,
-    NodeInfoDO,
-    OSSOperationInfoDO,
-    ResourceOSSSettingDO,
-    PodContainerDO,
-    InstanceTypeWithStatusDO,
-    NodeMetaDO,
-    CommandSettingDO,
-    SecretUserSettingDO,
-    SecretDO,
-    InstanceInfoDO,
-    ServiceDO,
-    PodOSSOperationInfoDO,
-    PodDO,
     InstanceTypeUserSettingDO,
+    SecretDO,
+    NamespaceDO,
+    DNSRecordDO,
+    NodeUserSettingDO,
+    PodContainerDO,
+    DeploymentDO,
+    CommandResultDO,
     InstanceUserSettingDO,
-    ConfigMapUserSettingDO
+    ConfigMapUserSettingDO,
+    IngressDO,
+    ConfigMapDO,
+    InstanceInfoDO,
+    NodeInfoDO,
+    ServiceDO,
+    SecretUserSettingDO,
+    PodDO,
+    InstanceTypeWithStatusDO,
+    CommandSettingDO,
+    PodOSSOperationInfoDO,
+    OSSOperationInfoDO,
+    NodeMetaDO,
+    ResourceOSSSettingDO,
+    ConditionDO
 )
 
 class ConditionConverter(Converter):
@@ -367,16 +367,7 @@ class NodeInfoConverter(Converter):
             security_group_id = [SecurityGroupID(m) for m in do.security_group_id],
             node_label = NodeLabel(do.node_label),
             cpu_number = Number(do.cpu_number),
-            cpu_usage = Usage(do.cpu_usage),
             memory_size = Size(do.memory_size),
-            actual_memory_size = Size(do.actual_memory_size),
-            memory_usage = Size(do.memory_usage),
-            flow_in = Size(do.flow_in),
-            flow_out = Size(do.flow_out),
-            disk_size = Size(do.disk_size),
-            disk_usage = Usage(do.disk_usage),
-            io_in = Number(do.io_in),
-            io_out = Number(do.io_out),
             gpu_type = GPUType(do.gpu_type),
             gpu_number = Number(do.gpu_number),
             instance_type_status = InstanceTypeStatus(do.instance_type_status),
@@ -413,16 +404,7 @@ class NodeInfoConverter(Converter):
             security_group_id = None if x.security_group_id is None else [m.get_value() for m in x.security_group_id],
             node_label = None if x.node_label is None else x.node_label.get_value(),
             cpu_number = None if x.cpu_number is None else x.cpu_number.get_value(),
-            cpu_usage = None if x.cpu_usage is None else x.cpu_usage.get_value(),
             memory_size = None if x.memory_size is None else x.memory_size.get_value(),
-            actual_memory_size = None if x.actual_memory_size is None else x.actual_memory_size.get_value(),
-            memory_usage = None if x.memory_usage is None else x.memory_usage.get_value(),
-            flow_in = None if x.flow_in is None else x.flow_in.get_value(),
-            flow_out = None if x.flow_out is None else x.flow_out.get_value(),
-            disk_size = None if x.disk_size is None else x.disk_size.get_value(),
-            disk_usage = None if x.disk_usage is None else x.disk_usage.get_value(),
-            io_in = None if x.io_in is None else x.io_in.get_value(),
-            io_out = None if x.io_out is None else x.io_out.get_value(),
             gpu_type = None if x.gpu_type is None else x.gpu_type.get_value(),
             gpu_number = None if x.gpu_number is None else x.gpu_number.get_value(),
             instance_type_status = None if x.instance_type_status is None else x.instance_type_status.get_value(),
